@@ -253,7 +253,9 @@ class Context {
                 encodedFrame,
                 keyIndex);
 
-            return controller.enqueue(decodedFrame);
+            if (decodedFrame) {
+                controller.enqueue(decodedFrame);
+            }
         }
     }
 
