@@ -26,10 +26,5 @@ module.exports = {
                 ios: null
             }
         }
-    },
-    project: {
-        ios: {
-            project: '.ios/jitsi-meet.xcworkspace'
-        }
     }
 };
